#! /bin/sh
# vim:sts=4 sw=4 ts=4 et ai foldmethod=marker
# set -x

bn0=`basename ${0}`
dn0=`dirname ${0}`
[ "${dn0}" = "." ] && dn0=`pwd`

quiet=0
verify=0
usage=0
force=0
export intCheck=0
for arg in ${@}; do #{{{
    case ${arg} in
        -quiet|-Q)          quiet=1 ;;
        -verify|-V)         verify=1 ;;
        -force|-F)          force=1 ;;
	  -lang=*|-l=*)       language=1
				LangEntered=`echo ${arg} | cut -f2 -d=`;; 
        -help|-h|-H|-[?])   usage=1 ;;
    esac
done #}}}

if [ ${usage} -eq 1 ]; then #{{{
    . "${dn0}/.installer/config"
    [ -f "${dn0}/register" ] && with_buagent=1
    [ -f "${dn0}/set_language" ] && . "${dn0}/set_language" && DetermineSystemDefaultLanguage
    [ -z "${default_lang}" ] && default_lang=en-US
    Usage
    exit 0
fi #}}}
ChkCmdLangOption()
{
        case ${LangEntered} in
        de|DE|de-DE|de_DE) default_lang="de-DE"
                        intCheck=1 ;;
        fr|FR|fr-FR|fr_FR) default_lang="fr-FR"
                        intCheck=1 ;;
        es|ES|es-ES|es_ES) default_lang="es-ES"
                        intCheck=1 ;;
        en|EN|us|US|en-US|en_US) default_lang="en-US"
                        intCheck=1 ;;
        * )
            echo "Please enter the valid option"
    		. "${dn0}/.installer/config"
    		[ -f "${dn0}/register" ] && with_buagent=1
    		[ -f "${dn0}/set_language" ] && . "${dn0}/set_language" && DetermineSystemDefaultLanguage
    		[ -z "${default_lang}" ] && default_lang=en-US
                Usage
                exit 0 ;;
        esac
}
if [ "${language}" -eq 1 ]; then #{{{
	ChkCmdLangOption
fi #}}}

# {{{ Verify that the package has everything it's supposed to.
[ ${quiet} -eq 0 ] && printf "Verifying installer integrity... "

if [ ! -s "${dn0}/.manifest" ]; then #{{{
    [ ${quiet} -eq 0 ] && cat - <<EOS

The installer is corrupt. No manifest can be found.
EOS
    exit 1
fi #}}}

for entry in `cat "${dn0}/.manifest"`; do #{{{
    sum=`echo ${entry} | cut -d: -f1`
    file=`echo ${entry} | cut -d: -f2`

    if [ ! -f "${dn0}${file}" ]; then #{{{
        [ ${quiet} -eq 0 ] && cat - <<EOS
The installer is corrupt.

It cannot find file ${file}.
EOS
        exit 1
    fi #}}}

    if [ ! -z "${sum}" ]; then #{{{
        newsum=`cksum "${dn0}/${file}" | awk '{ print $1; }'`

        if [ "${sum}" != "${newsum}" ]; then #{{{
            [ ${quiet} -eq 0 ] && cat - <<EOS

The installer is corrupt.

The checksum for ${file} does not match.
  Found:    ${newsum}
  Expected: ${sum}
EOS

            if [ ${force} -eq 0 ]; then #{{{
                exit 1
            fi #}}}
        fi #}}}
    fi #}}}
done #}}}
[ ${quiet} -eq 0 ] && echo "OK."

[ ${verify} -eq 1 ] && exit 0
#}}}

. "${dn0}/.installer/config"
. "${dn0}/.installer/pre-install"

[ ${quiet} -eq 0 ] && printf "Verifying prerequisites... "
PlatformPrerequisites
Message "OK."

[ -f "${dn0}/set_language" ] && . "${dn0}/set_language"

Initialize ${@}

[ -f "${dn0}/register" ] && . "${dn0}/register"
[ -f "${dn0}/.installer/oracle" ] && . "${dn0}/.installer/oracle"
[ -f "${dn0}/.installer/smsplugin" ] && . "${dn0}/.installer/smsplugin"
[ -f "${dn0}/.installer/vmware" ] && . "${dn0}/.installer/vmware"

CheckPermissions
CheckRunning

InstallBanner

GetPreviousInstallDir
GetInstallDir

case ${pluginInstall} in #{{{
    0)  CheckInstallSpace #{{{
        Message Preparing for installation ...
        PrepareInstallation
        CheckValidVaults
        UpgradeControlFiles
        InstallCommonFiles
        InstallPlatformFiles
        [ ${with_buagent} -eq 1 ] && InstallBUAgent
        InstallStartup
	InstallXlogmore
        ;; #}}}
    1)  VerifyInstallation #{{{
        CheckInstallSpace
	Message Preparing for installation ...
        PrepareInstallation
        InstallPlugin
        RegisterPlugin
        ;; #}}}
esac #}}}

StartAgent

ChangeInstallationOwnership

LogMessage "Install finished at `date +'%H:%M:%S %Y.%m.%d'`"

if [ -d "${backup_dir}" ]; then #{{{
    LogMessage "Install successful. Removing install recovery directory:"
    LogMessage "${backup_dir}"
    rm -rf "${backup_dir}" 2> /dev/null > /dev/null
    if [ -f "${init_dir}"/vvagent.${install_time} ]; then #{{{
        rm -f "${init_dir}"/vvagent.${install_time} 2> /dev/null > /dev/null
    fi #}}}
fi #}}}

if [ ${moveLog} -eq 1 ]; then #{{{
    CopyLog "${install_dir}"
    TellLog "${install_dir}"
fi #}}}

exit 0
